# https://aio-pika.readthedocs.io/en/latest/rabbitmq-tutorial/1-introduction.html
import json

try:
    import aio_pika

    HAS_LIBS = (True,)
except ImportError:
    HAS_LIBS = False, "aio_pika is not available"


def __virtual__(hub):
    return HAS_LIBS


async def publish(hub, ctx, event):
    if not ctx and not ctx.connected:
        return

    encoded_event = json.dumps(event).encode()
    message = aio_pika.Message(encoded_event)

    async with ctx.connection.channel() as channel:
        for routing_key in ctx.channels:
            await channel.default_exchange.publish(message, routing_key=routing_key)



import asyncio
import datetime
import random
from typing import AsyncGenerator


async def listen(hub) -> AsyncGenerator:
    i = 0
    hub.log.debug("started random data injector")
    while hub.evbus.RUN_FOREVER:
        randint = random.randint(0, 10000000)
        yield {
            "number": i,
            "timestamp": datetime.datetime.now().timestamp(),
            "data": f"{randint}".zfill(7),
        }
        i += 1
        await asyncio.sleep(1)


async def start(hub):
    async for event in hub.evbus.test.listen():
        await hub.evbus.BUS.put(event)
